@@ -22,6 +22,7 @@ import re
 from lib2to3 import pytree
 from lib2to3.pgen2 import token
 
+from yapf.yapflib import py3compat
 from yapf.yapflib import pytree_utils
 from yapf.yapflib import style
 
@@ -49,6 +50,7 @@ class Subtype(object):
   COMP_FOR = 12
   COMP_IF = 13
   DEFAULT_OR_NAMED_ASSIGN_ARG_LIST = 14
+  FUNC_DEF = 15
 
 
 class FormatToken(object):
@@ -85,8 +87,7 @@ class FormatToken(object):
     Arguments:
       node: (pytree.Leaf) The node that's being wrapped.
     """
-    assert isinstance(node, pytree.Leaf)
-    self._node = node
+    self.node = node
     self.next_token = None
     self.previous_token = None
     self.matching_bracket = None
@@ -111,18 +112,19 @@ class FormatToken(object):
       spaces: (int) The number of spaces to place before the token.
       indent_level: (int) The indentation level.
     """
-    spaces_before = (
-        ' ' * indent_level * style.Get('INDENT_WIDTH') + ' ' * spaces)
+    indent_char = '\t' if style.Get('USE_TABS') else ' '
+    indent_before = (
+        indent_char * indent_level * style.Get('INDENT_WIDTH') + ' ' * spaces)
 
     if self.is_comment:
       comment_lines = [s.lstrip() for s in self.value.splitlines()]
-      self._node.value = ('\n' + spaces_before).join(comment_lines)
+      self.node.value = ('\n' + indent_before).join(comment_lines)
 
     if not self.whitespace_prefix:
       self.whitespace_prefix = (
-          '\n' * (self.newlines or newlines_before) + spaces_before)
+          '\n' * (self.newlines or newlines_before) + indent_before)
     else:
-      self.whitespace_prefix += spaces_before
+      self.whitespace_prefix += indent_before
 
   def AdjustNewlinesBefore(self, newlines_before):
     """Change the number of newlines before this token."""
@@ -141,7 +143,7 @@ class FormatToken(object):
       prev_lineno += previous.value.count('\n')
 
     if (cur_lineno != prev_lineno or
-        (previous.is_pseudo_paren and
+        (previous.is_pseudo_paren and previous.value != ')' and
          cur_lineno != previous.previous_token.lineno)):
       self.spaces_required_before = (
           self.column - first_column + depth * style.Get('INDENT_WIDTH'))
@@ -167,108 +169,109 @@ class FormatToken(object):
   def ClosesScope(self):
     return self.value in pytree_utils.CLOSING_BRACKETS
 
-  def GetPytreeNode(self):
-    return self._node
-
-  @property
-  def value(self):
-    if self.is_continuation:
-      return self._node.value.rstrip()
-    return self._node.value
-
-  @property
-  def node(self):
-    return self._node
-
-  @property
-  def node_split_penalty(self):
-    """Split penalty attached to the pytree node of this token.
-
-    Returns:
-      The penalty, or None if no annotation is attached.
-    """
-    return pytree_utils.GetNodeAnnotation(self._node,
-                                          pytree_utils.Annotation.SPLIT_PENALTY,
-                                          default=0)
-
-  @property
-  def newlines(self):
-    """The number of newlines needed before this token."""
-    return pytree_utils.GetNodeAnnotation(self._node,
-                                          pytree_utils.Annotation.NEWLINES)
-
-  @property
-  def must_split(self):
-    """Return true if the token requires a split before it."""
-    return pytree_utils.GetNodeAnnotation(self._node,
-                                          pytree_utils.Annotation.MUST_SPLIT)
-
-  @property
-  def column(self):
-    """The original column number of the node in the source."""
-    return self._node.column
-
-  @property
-  def lineno(self):
-    """The original line number of the node in the source."""
-    return self._node.lineno
-
-  @property
-  def subtypes(self):
-    """Extra type information for directing formatting."""
-    value = pytree_utils.GetNodeAnnotation(self._node,
-                                           pytree_utils.Annotation.SUBTYPE)
-    return [Subtype.NONE] if value is None else value
-
-  @property
-  def is_binary_op(self):
-    """Token is a binary operator."""
-    return Subtype.BINARY_OPERATOR in self.subtypes
-
-  @property
-  def name(self):
-    """A string representation of the node's name."""
-    return pytree_utils.NodeName(self._node)
-
   def __repr__(self):
     msg = 'FormatToken(name={0}, value={1}'.format(self.name, self.value)
     msg += ', pseudo)' if self.is_pseudo_paren else ')'
     return msg
 
+  @property
+  def value(self):
+    if self.is_continuation:
+      return self.node.value.rstrip()
+    return self.node.value
+
+  @property
+  @py3compat.lru_cache()
+  def node_split_penalty(self):
+    """Split penalty attached to the pytree node of this token."""
+    return pytree_utils.GetNodeAnnotation(
+        self.node, pytree_utils.Annotation.SPLIT_PENALTY, default=0)
+
+  @property
+  def newlines(self):
+    """The number of newlines needed before this token."""
+    return pytree_utils.GetNodeAnnotation(self.node,
+                                          pytree_utils.Annotation.NEWLINES)
+
+  @property
+  def must_split(self):
+    """Return true if the token requires a split before it."""
+    return pytree_utils.GetNodeAnnotation(self.node,
+                                          pytree_utils.Annotation.MUST_SPLIT)
+
+  @property
+  def column(self):
+    """The original column number of the node in the source."""
+    return self.node.column
+
+  @property
+  def lineno(self):
+    """The original line number of the node in the source."""
+    return self.node.lineno
+
+  @property
+  @py3compat.lru_cache()
+  def subtypes(self):
+    """Extra type information for directing formatting."""
+    value = pytree_utils.GetNodeAnnotation(self.node,
+                                           pytree_utils.Annotation.SUBTYPE)
+    return [Subtype.NONE] if value is None else value
+
+  @property
+  @py3compat.lru_cache()
+  def is_binary_op(self):
+    """Token is a binary operator."""
+    return Subtype.BINARY_OPERATOR in self.subtypes
+
+  @property
+  @py3compat.lru_cache()
+  def name(self):
+    """A string representation of the node's name."""
+    return pytree_utils.NodeName(self.node)
+
   @property
   def is_comment(self):
-    return self._node.type == token.COMMENT
+    return self.node.type == token.COMMENT
 
   @property
   def is_continuation(self):
-    return self._node.type == CONTINUATION
+    return self.node.type == CONTINUATION
 
   @property
+  @py3compat.lru_cache()
   def is_keyword(self):
     return keyword.iskeyword(self.value)
 
   @property
+  @py3compat.lru_cache()
   def is_name(self):
-    return self._node.type == token.NAME and not self.is_keyword
+    return self.node.type == token.NAME and not self.is_keyword
 
   @property
   def is_number(self):
-    return self._node.type == token.NUMBER
+    return self.node.type == token.NUMBER
 
   @property
   def is_string(self):
-    return self._node.type == token.STRING
+    return self.node.type == token.STRING
 
   @property
+  @py3compat.lru_cache()
   def is_multiline_string(self):
     return (self.is_string and
             re.match(r'^[uUbB]?[rR]?(?P<delim>"""|\'\'\').*(?P=delim)$',
                      self.value, re.DOTALL) is not None)
 
   @property
+  @py3compat.lru_cache()
   def is_docstring(self):
     return self.is_multiline_string and not self.node.prev_sibling
 
   @property
+  @py3compat.lru_cache()
   def is_pseudo_paren(self):
-    return hasattr(self._node, 'is_pseudo') and self._node.is_pseudo
+    return hasattr(self.node, 'is_pseudo') and self.node.is_pseudo
+
+  @property
+  def is_pylint_comment(self):
+    return self.is_comment and re.match(r'#\s*\bpylint:\b', self.value)
