@@ -116,7 +116,10 @@ def _RetainVerticalSpacingBetweenTokens(cur_tok, prev_tok):
   if prev_tok.is_string:
     prev_lineno = prev_tok.lineno + prev_tok.value.count('\n')
   elif prev_tok.is_pseudo_paren:
-    prev_lineno = prev_tok.previous_token.lineno
+    if not prev_tok.previous_token.is_multiline_string:
+      prev_lineno = prev_tok.previous_token.lineno
+    else:
+      prev_lineno = prev_tok.lineno
   else:
     prev_lineno = prev_tok.lineno
 
@@ -230,7 +233,7 @@ def _FormatFinalLines(final_lines, verify):
         if (not tok.next_token.whitespace_prefix.startswith('\n') and
             not tok.next_token.whitespace_prefix.startswith(' ')):
           if (tok.previous_token.value == ':' or
-              tok.next_token.value not in frozenset(',}])')):
+              tok.next_token.value not in ',}])'):
             formatted_line.append(' ')
 
     formatted_code.append(''.join(formatted_line))
@@ -355,9 +358,8 @@ def _AddNextStateToQueue(penalty, previous_node, newline, count, p_queue):
     return count
 
   node = _StateNode(previous_node.state, newline, previous_node)
-  penalty += node.state.AddTokenToState(newline=newline,
-                                        dry_run=True,
-                                        must_split=must_split)
+  penalty += node.state.AddTokenToState(
+      newline=newline, dry_run=True, must_split=must_split)
   heapq.heappush(p_queue, _QueueItem(_OrderedPenalty(penalty, count), node))
   return count + 1
 
@@ -440,8 +442,7 @@ def _CalculateNumberOfNewlines(first_token, indent_depth, prev_uwline,
 
   prev_last_token = prev_uwline.last
   if prev_last_token.is_docstring:
-    if (not indent_depth and
-        first_token.value in frozenset({'class', 'def', 'async'})):
+    if (not indent_depth and first_token.value in {'class', 'def', 'async'}):
       # Separate a class or function from the module-level docstring with two
       # blank lines.
       return TWO_BLANK_LINES
@@ -451,7 +452,7 @@ def _CalculateNumberOfNewlines(first_token, indent_depth, prev_uwline,
     else:
       return ONE_BLANK_LINE
 
-  if first_token.value in frozenset({'class', 'def', '@'}):
+  if first_token.value in {'class', 'def', 'async', '@'}:
     # TODO(morbo): This can go once the blank line calculator is more
     # sophisticated.
     if not indent_depth:
@@ -477,7 +478,7 @@ def _CalculateNumberOfNewlines(first_token, indent_depth, prev_uwline,
                                            pytree_utils.Annotation.NEWLINES,
                                            None)
           return NO_BLANK_LINES
-    elif prev_uwline.first.value in frozenset({'class', 'def'}):
+    elif prev_uwline.first.value in {'class', 'def', 'async'}:
       if not style.Get('BLANK_LINE_BEFORE_NESTED_CLASS_OR_DEF'):
         pytree_utils.SetNodeAnnotation(first_token.node,
                                        pytree_utils.Annotation.NEWLINES, None)
@@ -521,9 +522,8 @@ def _SingleOrMergedLines(uwlines):
         if uwlines[index].lineno != uwline.lineno:
           break
         if uwline.last.value != ':':
-          leaf = pytree.Leaf(type=token.SEMI,
-                             value=';',
-                             context=('', (uwline.lineno, column)))
+          leaf = pytree.Leaf(
+              type=token.SEMI, value=';', context=('', (uwline.lineno, column)))
           uwline.AppendToken(format_token.FormatToken(leaf))
         for tok in uwlines[index].tokens:
           uwline.AppendToken(tok)
