@@ -1,4 +1,4 @@
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015-2016 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -188,18 +188,18 @@ class SplitPenaltyTest(unittest.TestCase):
     tree = self._ParseAndComputePenalties(code)
     self._CheckPenalties(tree, [
         ('[', None),
-        ('a', CONTIGUOUS_LIST),
-        ('for', 0),
+        ('a', STRONGLY_CONNECTED),
+        ('for', STRONGLY_CONNECTED),
         ('a', STRONGLY_CONNECTED),
         ('in', STRONGLY_CONNECTED),
         ('foo', STRONGLY_CONNECTED),
-        ('if', 0),
+        ('if', STRONGLY_CONNECTED),
         ('a', STRONGLY_CONNECTED),
         ('.', UNBREAKABLE),
         ('x', DOTTED_NAME),
         ('==', STRONGLY_CONNECTED),
         ('37', STRONGLY_CONNECTED),
-        (']', CONTIGUOUS_LIST),
+        (']', STRONGLY_CONNECTED),
     ])  # yapf: disable
 
   def testFuncCalls(self):
@@ -221,10 +221,10 @@ class SplitPenaltyTest(unittest.TestCase):
     self._CheckPenalties(tree, [
         ('foo', None),
         ('.', UNBREAKABLE),
-        ('bar', UNBREAKABLE),
-        ('.', UNBREAKABLE),
-        ('baz', UNBREAKABLE),
-        ('(', UNBREAKABLE),
+        ('bar', DOTTED_NAME),
+        ('.', STRONGLY_CONNECTED),
+        ('baz', DOTTED_NAME),
+        ('(', STRONGLY_CONNECTED),
         ('1', CONTIGUOUS_LIST),
         (',', CONTIGUOUS_LIST),
         ('2', CONTIGUOUS_LIST),
